@@ -1,9 +1,9 @@
-//@line 37 "/mnt/Srcs/Firefox/build/toolkit/components/url-classifier/src/nsUrlClassifierListManager.js"
+//@line 37 "/home/karma/src/build/build/toolkit/components/url-classifier/src/nsUrlClassifierListManager.js"
 
 const Cc = Components.classes;
 const Ci = Components.interfaces;
 
-//@line 37 "/mnt/Srcs/Firefox/build/toolkit/components/url-classifier/content/listmanager.js"
+//@line 37 "/home/karma/src/build/build/toolkit/components/url-classifier/content/listmanager.js"
 
 
 // A class that manages lists, namely white and black lists for
@@ -412,7 +412,7 @@ PROT_ListManager.prototype.makeUpdateRequest_ = function(tableData) {
   // For each requested table that didn't have chunk data in the database,
   // request it fresh
   for (var tableName in tableNames) {
-    request += tableName + ";:mac\n";
+    request += tableName + ";mac\n";
   }
 
   G_Debug(this, 'checkForUpdates: scheduling request..');
@@ -537,7 +537,7 @@ PROT_ListManager.prototype.QueryInterface = function(iid) {
   Components.returnCode = Components.results.NS_ERROR_NO_INTERFACE;
   return null;
 }
-//@line 42 "/mnt/Srcs/Firefox/build/toolkit/components/url-classifier/src/nsUrlClassifierListManager.js"
+//@line 42 "/home/karma/src/build/build/toolkit/components/url-classifier/src/nsUrlClassifierListManager.js"
 
 var modScope = this;
 function Init() {
