@@ -133,7 +133,7 @@ pref("keyword.URL", "chrome://browser-region/locale/region.properties");
 
 pref("general.useragent.locale", "ja");
 pref("general.skins.selectedSkin", "classic/1.0");
-pref("general.useragent.extra.firefox", "Minefield/3.0.10");
+pref("general.useragent.extra.firefox", "GranParadiso/3.0.11");
 
 pref("general.smoothScroll", false);
 //@line 180 "/home/karma/src/build/build/browser/app/profile/firefox.js"
